"""
Simple sendmail script
"""

import smtplib
import sys
import getpass

def send(mailhost, sender, recipients, subj, body, auth=None, debug=False):
    "Send a single message to a list of recipients"
    def log_debug(msg):
        "Print debug messages"
        if _debug:
            print("DBG>", msg)
    _debug = debug
    header = '\r\n'.join(("From: %s" % sender,
                          "To: %s" % ', '.join(recipients),
                          "Subject: %s" % subj,
                          ""))
    body = '\r\n'.join(body)
    log_debug('Opening connection to: %s' % mailhost)
    try:
        server = smtplib.SMTP(mailhost)
        if auth:
            server.starttls()
            log_debug('Login as %s ...' % auth[0])
            server.login(auth[0], auth[1])
        log_debug('Sendmail ...')
        server.sendmail(sender, recipients, str(header)+str(body))
        log_debug('quit ...')
        server.quit()
    except Exception as excp:
        print("SMTP exception:", str(excp))

def main():
    """
Test code usage:

    1. python simplemail.py server.net rec@pient.com
       (to send through unauthenticated server)

    2. python simplemail.py server.net userid rec@pient.com
       (to send through authenticated server)
"""
    sender = 'fake.sender@somewhere.eu'
    subj_fmt = 'Test message via %s'
    msg_body = ['', 'Test message generated by simplemail.py', '']

    if len(sys.argv) == 3: # Sending via non authenticating server
        subj = subj_fmt % sys.argv[1]
        print("Sending: ", subj)
        send(sys.argv[1], sender, [sys.argv[2]],
             subj, msg_body, debug=True)

    elif len(sys.argv) == 4: # Sending via authenticating server
        pwd = getpass.getpass(prompt="Password for %s: "%sys.argv[2])
        subj = subj_fmt % sys.argv[1]
        print("Sending: ", subj)
        send(sys.argv[1], sender, [sys.argv[3]],
             subj, msg_body, auth=(sys.argv[2], pwd), debug=True)
    else:
        print(main.__doc__)

if __name__ == '__main__':
    main()
